=======
Credits
=======

Development Lead
----------------

* Felippe da Motta Raposo <raposo.felippe@gmail.com>
* Ricardo Dias <ricardo@ricardodias.org>

Contributors
------------

None yet. Why not be the first?